@@ -14,22 +14,22 @@ headers = {
     'Authorization': get_driver().config.api_token
 }
 
-async def get_BindInfo(user,info):
+async def get_BindInfo(server_type,user,info):
     try:
         url,params = '',''
         if isinstance(info,List) and len(info) == 1:
             for i in info:              #是否包含me或@
                 if str(i).lower() == 'me':
-                    url = 'https://api.wows.linxun.link/public/wows/bind/account/platform/bind/list'
+                    url = 'https://api.wows.shinoaki.com/public/wows/bind/account/platform/bind/list'
                     params = {
-                    "platformType": "QQ",
+                    "platformType": server_type,
                     "platformId": user,
                     }
                 match = re.search(r"CQ:at,qq=(\d+)",i)
                 if match:
-                    url = 'https://api.wows.linxun.link/public/wows/bind/account/platform/bind/list'
+                    url = 'https://api.wows.shinoaki.com/public/wows/bind/account/platform/bind/list'
                     params = {
-                    "platformType": "QQ",
+                    "platformType": server_type,
                     "platformId": match.group(1),
                     }
                     break
@@ -39,7 +39,7 @@ async def get_BindInfo(user,info):
             return '参数似乎出了问题呢，请使用me或@群友'
         logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
         async with httpx.AsyncClient(headers=headers) as client:
-            resp = await client.get(url, params=params, timeout=10)
+            resp = await client.get(url, params=params, timeout=None)
             result = resp.json()
             logger.info(f"本次请求返回的状态码:{result['code']}")
         if result['code'] == 200 and result['message'] == "success":
@@ -67,7 +67,7 @@ async def get_BindInfo(user,info):
         logger.error(traceback.format_exc())
         return 'wuwuwu出了点问题，请联系麻麻解决'
     
-async def set_BindInfo(user,info):
+async def set_BindInfo(server_type,user,info):
     try:
         param_server = None
         if isinstance (info,List):
@@ -75,17 +75,15 @@ async def set_BindInfo(user,info):
                 param_server,info = await match_keywords(info,servers)
                 if param_server:
                     param_accountid = await get_AccountIdByName(param_server,str(info[0]))
-                    if param_accountid and param_accountid != 404:
-                        url = 'https://api.wows.linxun.link/api/wows/bind/account/platform/bind/put'
+                    if isinstance(param_accountid,int):
+                        url = 'https://api.wows.shinoaki.com/api/wows/bind/account/platform/bind/put'
                         params = {
-                        "platformType": "QQ",
+                        "platformType": server_type,
                         "platformId": str(user),
                         "accountId": param_accountid
                         }
-                    elif param_accountid == 404:
-                        return '无法查询该游戏昵称Orz，请检查昵称是否存在'
                     else:
-                        return '发生了错误，有可能是网络波动，请稍后再试'
+                        return f"{param_accountid}"
                 else:
                     return '服务器参数似乎输错了呢'
             else:
@@ -94,7 +92,7 @@ async def set_BindInfo(user,info):
             return '参数似乎输错了呢，请确保后面跟随服务器+游戏昵称'
         logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
         async with httpx.AsyncClient(headers=headers) as client:
-            resp = await client.get(url, params=params, timeout=20)
+            resp = await client.get(url, params=params, timeout=None)
             result = resp.json()
             logger.info(f"本次请求返回的状态码:{result['code']}")
         if result['code'] == 200 and result['message'] == "success":
@@ -110,19 +108,19 @@ async def set_BindInfo(user,info):
         logger.error(traceback.format_exc())
         return 'wuwuwu出了点问题，请联系麻麻解决'
 
-async def change_BindInfo(user,info):
+async def change_BindInfo(server_type,user,info):
     try:
-        if isinstance(info,List) and len(info) == 1 and str(info[0]).isdigit:
-            url = 'https://api.wows.linxun.link/public/wows/bind/account/platform/bind/list'
+        if isinstance(info,List) and len(info) == 1 and str(info[0]).isdigit():
+            url = 'https://api.wows.shinoaki.com/public/wows/bind/account/platform/bind/list'
             params = {
-            "platformType": "QQ",
+            "platformType": server_type,
             "platformId": user,
             }
         else:
             return '参数似乎出了问题呢，请跟随要切换的序号'
         logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
         async with httpx.AsyncClient(headers=headers) as client:
-            resp = await client.get(url, params=params, timeout=10)
+            resp = await client.get(url, params=params, timeout=None)
             result = resp.json()
             logger.info(f"本次请求返回的状态码:{result['code']}")
         if result['code'] == 200 and result['message'] == "success":
@@ -130,9 +128,9 @@ async def change_BindInfo(user,info):
                 account_name = result['data'][int(info[0])-1]['userName']
                 param_server = result['data'][int(info[0])-1]['serverType']
                 param_accountid = result['data'][int(info[0])-1]['accountId']
-                url = 'https://api.wows.linxun.link/api/wows/bind/account/platform/bind/put'
+                url = 'https://api.wows.shinoaki.com/api/wows/bind/account/platform/bind/put'
                 params = {
-                "platformType": "QQ",
+                "platformType": server_type,
                 "platformId": str(user),
                 "accountId": param_accountid
                 }
@@ -143,7 +141,7 @@ async def change_BindInfo(user,info):
         else:
             return f"{result['message']}"
         async with httpx.AsyncClient(headers=headers) as client:
-            resp = await client.get(url, params=params, timeout=10)
+            resp = await client.get(url, params=params, timeout=None)
             result = resp.json()
         if result['code'] == 200 and result['message'] == "success":
             return f'切换绑定成功,当前绑定账号{param_server}：{account_name}'
@@ -160,7 +158,7 @@ async def change_BindInfo(user,info):
         logger.error(traceback.format_exc())
         return 'wuwuwu出了点问题，请联系麻麻解决'
     
-async def set_special_BindInfo(user,info):
+async def set_special_BindInfo(server_type,user,info):
     try:
         param_server = None
         if isinstance (info,List):
@@ -168,9 +166,9 @@ async def set_special_BindInfo(user,info):
                 param_server,info = await match_keywords(info,servers)
                 if param_server:
                     if str(info[0]).isdigit():
-                        url = 'https://api.wows.linxun.link/api/wows/bind/account/platform/bind/put'
+                        url = 'https://api.wows.shinoaki.com/api/wows/bind/account/platform/bind/put'
                         params = {
-                        "platformType": "QQ",
+                        "platformType": server_type,
                         "platformId": str(user),
                         "accountId": int(info[0])
                         }
@@ -184,7 +182,7 @@ async def set_special_BindInfo(user,info):
             return '参数似乎输错了呢，请确保后面跟随服务器+游戏昵称'
         logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
         async with httpx.AsyncClient(headers=headers) as client:
-            resp = await client.get(url, params=params, timeout=20)
+            resp = await client.get(url, params=params, timeout=None)
             result = resp.json()
             logger.info(f"本次请求返回的状态码:{result['code']}")
         if result['code'] == 200 and result['message'] == "success":
@@ -200,27 +198,27 @@ async def set_special_BindInfo(user,info):
         logger.error(traceback.format_exc())
         return 'wuwuwu出了点问题，请联系麻麻解决'
     
-async def delete_BindInfo(user,info):
+async def delete_BindInfo(server_type,user,info):
     try:
-        if isinstance(info,List) and len(info) == 1 and str(info[0]).isdigit:
-            url = 'https://api.wows.linxun.link/public/wows/bind/account/platform/bind/list'
+        if isinstance(info,List) and len(info) == 1 and str(info[0]).isdigit():
+            url = 'https://api.wows.shinoaki.com/public/wows/bind/account/platform/bind/list'
             params = {
-            "platformType": "QQ",
+            "platformType": server_type,
             "platformId": user,
             }
         else:
             return '参数似乎出了问题呢，请跟随要切换的序号'
         async with httpx.AsyncClient(headers=headers) as client:
-            resp = await client.get(url, params=params, timeout=10)
+            resp = await client.get(url, params=params, timeout=None)
             result = resp.json()
         if result['code'] == 200 and result['message'] == "success":
             if result['data'] and len(result['data']) >= int(info[0]):
                 account_name = result['data'][int(info[0])-1]['userName']
                 param_server = result['data'][int(info[0])-1]['serverType']
                 param_accountid = result['data'][int(info[0])-1]['accountId']
-                url = 'https://api.wows.linxun.link/api/wows/bind/account/platform/bind/remove'
+                url = 'https://api.wows.shinoaki.com/api/wows/bind/account/platform/bind/remove'
                 params = {
-                "platformType": "QQ",
+                "platformType": server_type,
                 "platformId": str(user),
                 "accountId": param_accountid
                 }
@@ -232,7 +230,7 @@ async def delete_BindInfo(user,info):
             return f"{result['message']}"
         logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
         async with httpx.AsyncClient(headers=headers) as client:
-            resp = await client.get(url, params=params, timeout=10)
+            resp = await client.get(url, params=params, timeout=None)
             result = resp.json()
             logger.info(f"本次请求返回的状态码:{result['code']}")
         if result['code'] == 200 and result['message'] == "success":
