@@ -23,40 +23,35 @@ headers = {
     'Authorization': get_driver().config.api_token
 }
   
-async def get_AccountInfo(qqid,info):
+async def get_AccountInfo(server_type,qqid,info):
     try:
         url,params = '',''
         if isinstance(info,List):
             for i in info:
                 if str(i).lower() == 'me':
-                    url = 'https://api.wows.linxun.link/public/wows/account/v2/user/info'
                     params = {
-                    "server": "QQ",
-                    "accountId": str(qqid)
+                    "server": server_type,
+                    "accountId": int(qqid)
                     }
                     break
                 match = re.search(r"CQ:at,qq=(\d+)",i)
                 if match:
-                    url = 'https://api.wows.linxun.link/public/wows/account/v2/user/info'
                     params = {
-                    "server": "QQ",
-                    "accountId": match.group(1)
+                    "server": server_type,
+                    "accountId": int(match.group(1))
                     }
                     break
             if not params and len(info) == 2:
                 param_server,info = await match_keywords(info,servers)
                 if param_server:
                     param_accountid = await get_AccountIdByName(param_server,str(info[0]))
-                    if param_accountid and param_accountid != 404:
-                        url = 'https://api.wows.linxun.link/public/wows/account/v2/user/info'
+                    if isinstance(param_accountid,int):
                         params = {
                         "server": param_server,
                         "accountId": param_accountid
                         }
-                    elif param_accountid == 404:
-                        return '无法查询该游戏昵称Orz，请检查昵称是否存在'
                     else:
-                        return '发生了错误，有可能是网络波动，请稍后再试'
+                        return f"{param_accountid}"
                 else:
                     return '服务器参数似乎输错了呢'
             elif params:
@@ -65,9 +60,10 @@ async def get_AccountInfo(qqid,info):
                 return '您似乎准备用游戏昵称查询，请检查参数中是否包含服务器和游戏昵称，以空格区分，如果您准备查询单船战绩，请带上ship参数'
         else:
             return '参数似乎出了问题呢'
+        url = 'https://api.wows.shinoaki.com/public/wows/account/v4/user/info'
         logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
         async with httpx.AsyncClient(headers=headers) as client:
-            resp = await client.get(url, params=params, timeout=20)
+            resp = await client.get(url, params=params, timeout=None)
             result = resp.json()
             logger.info(f"本次请求返回的状态码:{result['code']}")
             logger.info(f"本次请求服务器计算时间:{result['queryTime']}")
