@@ -25,7 +25,7 @@ headers = {
 }
 
 
-async def get_RecentInfo(qqid,info):
+async def get_RecentInfo(server_type,qqid,info):
     try:
         params,day = None,0
         if datetime.now().hour < 7:
@@ -37,19 +37,17 @@ async def get_RecentInfo(qqid,info):
                     info.remove(i)
             for i in info:              #是否包含me或@，包含则调用平台接口
                 if i == 'me':
-                    url = 'https://api.wows.linxun.link//api/wows/recent/v2/recent/info'
                     params = {
-                    "server": "QQ",
-                    "accountId": qqid,
+                    "server": server_type,
+                    "accountId": int(qqid),
                     "day": day,
                     "status": 0
                     }
                 match = re.search(r"CQ:at,qq=(\d+)",i)
                 if match:
-                    url = 'https://api.wows.linxun.link//api/wows/recent/v2/recent/info'
                     params = {
-                    "server": "QQ",
-                    "accountId": match.group(1),
+                    "server": server_type,
+                    "accountId": int(match.group(1)),
                     "day": day,
                     "status": 0
                     }
@@ -58,18 +56,15 @@ async def get_RecentInfo(qqid,info):
                 param_server,info = await match_keywords(info,servers)
                 if param_server:
                     param_accountid = await get_AccountIdByName(param_server,str(info[0]))
-                    if param_accountid and param_accountid != 404:
-                        url = 'https://api.wows.linxun.link//api/wows/recent/v2/recent/info'
+                    if isinstance(param_accountid,int):
                         params = {
                         "server": param_server,
                         "accountId": param_accountid,
                         "day": day,
                         "status": 0
                         }
-                    elif param_accountid == 404:
-                        return '无法查询该游戏昵称Orz，请检查昵称是否存在'
                     else:
-                        return '发生了错误，有可能是网络波动，请稍后再试'
+                        return f"{param_accountid}"
                 else:
                     return '服务器参数似乎输错了呢'
             elif params:
@@ -78,9 +73,10 @@ async def get_RecentInfo(qqid,info):
                 return '您似乎准备用游戏昵称查询水表，请检查参数中是否包含服务器和游戏昵称，以空格区分'
         else:
             return '参数似乎出了问题呢'
+        url = 'https://api.wows.shinoaki.com//api/wows/recent/v2/recent/info'
         logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
         async with httpx.AsyncClient(headers=headers) as client:
-            resp = await client.get(url, params=params, timeout=20)
+            resp = await client.get(url, params=params, timeout=None)
             result = resp.json()
             logger.info(f"本次请求返回的状态码:{result['code']}")
         if result['code'] == 200:
