@@ -7,7 +7,6 @@ from nonebot.adapters.onebot.v11 import MessageSegment
 from .data_source import servers,set_shipparams,tiers,number_url_homes,set_ShipRank_Numbers
 from .utils import match_keywords
 from nonebot_plugin_htmlrender import html_to_pic,text_to_pic
-from .publicAPI import get_AccountIdByName
 from .wws_ship import ShipSecletProcess,ShipSlectState
 from.publicAPI import get_ship_byName
 from bs4 import BeautifulSoup
@@ -88,13 +87,13 @@ async def search_ShipRank_Yuyuko(shipId,server):
     try:
         content = None
         async with httpx.AsyncClient(headers=headers) as client:        #查询是否有缓存
-            url = 'https://api.wows.linxun.link/upload/numbers/data/v2/upload/ship/rank'
+            url = 'https://api.wows.shinoaki.com/upload/numbers/data/v2/upload/ship/rank'
             params = {
                 "server":server,
                 "shipId":int(shipId)
             }
             logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
-            resp = await client.get(url, params=params,timeout=20)
+            resp = await client.get(url, params=params,timeout=None)
             result = resp.json()
             logger.info(f"本次请求返回的状态码:{result['code']}")
             if result['code'] == 200 and result['data']:
@@ -116,7 +115,7 @@ async def search_ShipRank_Numbers(url,server,shipId):
         content = None
         logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}")
         async with httpx.AsyncClient() as client:
-            resp = await client.get(url, timeout=20)
+            resp = await client.get(url, timeout=None)
             logger.info(f"下面是本次请求返回的状态码，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{resp.status_code}")
         soup = BeautifulSoup(resp.content, 'html.parser')
         data = soup.select('tr[class="cells-middle"]')
@@ -135,8 +134,8 @@ async def search_ShipRank_Numbers(url,server,shipId):
 async def post_ShipRank(data):
     try:
         async with httpx.AsyncClient(headers=headers) as client:
-            url = 'https://api.wows.linxun.link/upload/numbers/data/v2/upload/ship/rank'
-            resp = await client.post(url, json = data, timeout=20)
+            url = 'https://api.wows.shinoaki.com/upload/numbers/data/v2/upload/ship/rank'
+            resp = await client.post(url, json = data, timeout=None)
             result = resp.json()
             logger.info(result)
     except (TimeoutError, ConnectTimeout):
